'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _ = require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The TinyLetter component acts as a wrapper
 * for the subscription form. It automatically populates
 * itself with input fields if no children are added.
 * You can also manually add the children elements.
 * Below are some examples of the various implementations.
 *
 * ## Using the auto-injected inputs
 *
 * ```jsx
 * { TinyLetter } from 'react-tinyletter';
 * ...
 * <TinyLetter list="YourTinyLetterUsername"/>
 * ```
 *
 * ## Using the included input components
 *
 * ```jsx
 * import { TinyLetter, Email, Submit } from 'react-tinyletter';
 * ...
 * <TinyLetter list="YourTinyLetterUsername">
 *   <Email/>
 *   <Submit/>
 * </TinyLetter>
 * ```
 * 
 * ## Using input primitives
 *
 * ```jsx
 * import { TinyLetter } from 'react-tinyletter';
 * ...
 * <TinyLetter list="YourTinyLetterUsername">
 *   <input type="email"/>
 *   <input type="submit" value="Subscribe"/>
 * </TinyLetter>
 * ```
 * 
 * You need not worry about assigning the `name` or `id`
 * properties on form inputs, they will automatically get
 * added by the `TinyLetter` component. **However**, make
 * sure that you use the correct `type` on your input fields
 * if using primitives, as the `type` is how the `TinyLetter`
 * component is able to determine which `input` is which.
 *
 * @param {object} props - jsx attributes
 * @return {ReactElement} - form wrapper markup
 */
function TinyLetter(props) {
  function subscribe() {
    window.open('https://tinyletter.com/' + props.list, 'popupwindow', 'scrollbars=yes,width=800,height=600');
    return true;
  }
  var children = props.children ? _react2.default.Children.map(props.children, function (child) {
    return child.props.type === 'email' ? _react2.default.cloneElement(child, {
      name: 'email',
      required: true
    }) : child;
  }) : _react2.default.createElement(
    'div',
    null,
    _react2.default.createElement(_.Email, null),
    _react2.default.createElement(_.Submit, null)
  );
  return _react2.default.createElement(
    'form',
    _extends({
      action: 'https://tinyletter.com/' + props.list,
      method: 'post',
      target: 'popupwindow',
      onSubmit: subscribe
    }, props),
    _react2.default.createElement('input', { type: 'hidden', value: '1', name: 'embed' }),
    children
  );
}

TinyLetter.propTypes = {
  children: _propTypes2.default.node,
  list: _propTypes2.default.string
};

exports.default = TinyLetter;